@@ -4,20 +4,20 @@ from .messages import (
 from .exceptions import get_error_class
 from . import exceptions
 from .aggregate import BaseAggregate
-from.response import DDDResponse
+from .response import DDDResponse
 from .repository import AbstractAsyncRepository, AbstractSyncRepository
 from .unit_of_work import AbstractAsyncUnitOfWork, AbstractSyncUnitOfWork
 from .messagebus import (
     BaseExternalMessageBus,
     AbstractAsyncExternalMessageBus,
     AbstractSyncExternalMessageBus,
-    MessageBus, AsyncMessageBus
+    MessageBus,
+    AsyncMessageBus
 )
 
-__all__ = ['fields', 'get_message_class', 'DDDStructure', 'DDDEvent', 'DDDCommand',  'DDDResponse',
+__all__ = ['fields', 'get_message_class', 'DDDStructure', 'DDDEvent', 'DDDCommand', 'DDDResponse',
            'get_error_class', 'exceptions', 'BaseAggregate',
            'AbstractAsyncRepository', 'AbstractSyncRepository',
            'AbstractAsyncUnitOfWork', 'AbstractSyncUnitOfWork',
            'MessageBus', 'AsyncMessageBus',
            'BaseExternalMessageBus', 'AbstractAsyncExternalMessageBus', 'AbstractSyncExternalMessageBus']
-
